package com.bonus.sgzb.machine.mapper;

import com.bonus.sgzb.machine.damain.MaPropInfo;

import java.util.List;

/**
 * 资产管理ma_prop_info(MaPropInfo)表数据库访问层
 *
 * @author makejava
 * @since 2023-11-28 10:18:07
 */
public interface MaPropInfoMapper {

    /**
     * 根据资产名称查询资产属性列表
     * @param propName
     * @return
     */
    List<MaPropInfo> selectMaPropSet(String propName);

    /**
     * 校验资产项目名称唯一性
     * @param propName
     * @return
     */
    MaPropInfo checkPropNameUnique(String propName);

    /**
     * 新增资产项目
     * @param maPropInfo
     * @return
     */
    int insertProp(MaPropInfo maPropInfo);

    /**
     * 删除资产项目
     * @param propId
     * @return
     */
    int deleteMaProp(Long propId);

    /**
     * 修改资产属性
     * @param maPropInfo
     * @return
     */
    int updateMaProp(MaPropInfo maPropInfo);
}

